import React, {useState} from 'react';
import ReactDOM from 'react-dom';
import { path, select, scaleOrdinal } from 'd3';

const height = 470;
const width = 520;
const margin = { top: 25, bottom: 25, right: 50, left: 50 };

const App = () => {
  const [hoverArc, setHoverArc] = useState(-1);
 	const data = [
    {'x': 'a', 'y': 1 },
    {'x': 'b', 'y': 2 },
    {'x': 'c', 'y': 1 },
    {'x': 'd', 'y': 5 },
  ];
  
  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;
  
  const outerRadius = 200;
  const innerRadius = 140;
  
  const arc = d3.arc().innerRadius(innerRadius).outerRadius(outerRadius);
  const hoveredArc = d3.arc().innerRadius(innerRadius - 20).outerRadius(outerRadius + 20);
  
  const d = {'a': 1, 'b': 2, 'c': 1, 'd': 3 };
  const colorScale = scaleOrdinal().domain(data.map(d => d['x'])).range(['yellow', 'red', 'blue', 'green']);
  const pie = d3.pie().padAngle(0.04).value(d => d['y']);
  const arcs = pie(data);
  const filteredArcs = arcs.filter(arc => arc.index === hoverArc);
  
  return (
  	<svg width={width} height={height} style={{border: '1px solid black'}}>
      <g transform={`translate(${margin.left},${margin.top})`}>
        <g transform={`translate(${innerWidth/2},${innerHeight/2})`}>
          {
          	filteredArcs.map(d => <path d={hoveredArc(d)} fill={colorScale(d.data['x'])} />)
          }
          {
          	arcs.map(d => <path d={arc(d)} fill={colorScale(d.data['x'])} onMouseEnter={() => setHoverArc(d.index)} onMouseLeave={() => setHoverArc(-1)}/>)
          }
        </g>
      </g>
    </svg>
  );
  
}

ReactDOM.render(<App />, document.getElementById('root'));
